@@ -6,4 +6,7 @@ def dict_to_pretty_string(the_dict, indent=4):
         return "{}"
 
     return ("\n" + " " * indent).join(
-        json.dumps(the_dict, sort_keys=True, indent=indent, separators=(',', ': ')).splitlines())
+        json.dumps(
+            the_dict, sort_keys=True, indent=indent, separators=(",", ": ")
+        ).splitlines()
+    )
